@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 1999-2006 Jeffrey Stedfast
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -51,13 +51,18 @@ typedef struct _GMimeCharset {
 } GMimeCharset;
 
 void g_mime_charset_init (GMimeCharset *charset);
-
 void g_mime_charset_step (GMimeCharset *charset, const char *in, size_t len);
-
 const char *g_mime_charset_best_name (GMimeCharset *charset);
 
 const char *g_mime_charset_best (const char *in, size_t inlen);
 
+gboolean g_mime_charset_can_encode (GMimeCharset *mask, const char *charset,
+				    const char *text, size_t len);
+
+
+void g_mime_set_user_charsets (const char **charsets);
+const char **g_mime_user_charsets (void);
+
 
 G_END_DECLS
 
