@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -28,29 +25,10 @@
 #include <ctype.h>
 #include <string.h>
 
+#include "gmime-common.h"
 #include "gmime-disposition.h"
 
 
-static int
-param_equal (gconstpointer v, gconstpointer v2)
-{
-	return strcasecmp ((const char *) v, (const char *) v2) == 0;
-}
-
-static guint
-param_hash (gconstpointer key)
-{
-	const char *p = key;
-	guint h = tolower (*p);
-	
-	if (h)
-		for (p += 1; *p != '\0'; p++)
-			h = (h << 5) - h + tolower (*p);
-	
-	return h;
-}
-
-
 /**
  * g_mime_disposition_new:
  * @disposition: disposition header (and params)
@@ -83,7 +61,7 @@ g_mime_disposition_new (const char *disposition)
 	while (*inptr && *inptr != ';')
 		inptr++;
 	
-	value = g_strndup (disposition, (unsigned) (inptr - disposition));
+	value = g_strndup (disposition, (size_t) (inptr - disposition));
 	g_strstrip (value);
 	
 	new->disposition = value;
@@ -91,7 +69,7 @@ g_mime_disposition_new (const char *disposition)
 	/* parse the parameters, if any */
 	if (*inptr++ == ';' && *inptr) {
 		param = new->params = g_mime_param_new_from_string (inptr);
-		new->param_hash = g_hash_table_new (param_hash, param_equal);
+		new->param_hash = g_hash_table_new (g_mime_strcase_hash, g_mime_strcase_equal);
 		while (param) {
 			g_hash_table_insert (new->param_hash, param->name, param);
 			param = param->next;
@@ -191,7 +169,7 @@ g_mime_disposition_add_parameter (GMimeDisposition *disposition, const char *att
 	} else {
 		/* hash table may not be initialized */
 		if (!disposition->param_hash)
-			disposition->param_hash = g_hash_table_new (param_hash, param_equal);
+			disposition->param_hash = g_hash_table_new (g_mime_strcase_hash, g_mime_strcase_equal);
 	}
 	
 	if (param == NULL) {
