@@ -289,6 +289,7 @@ gpg_ctx_new (GMimeSession *session, const char *path)
 	gpg->seen_eof2 = FALSE;
 	gpg->pid = (pid_t) -1;
 	gpg->exit_status = 0;
+	gpg->flushed = FALSE;
 	gpg->exited = FALSE;
 	
 	gpg->path = g_strdup (path);
@@ -315,6 +316,7 @@ gpg_ctx_new (GMimeSession *session, const char *path)
 	gpg->need_id = NULL;
 	gpg->passwd = NULL;
 	
+	gpg->nodata = FALSE;
 	gpg->badsig = FALSE;
 	gpg->errsig = FALSE;
 	gpg->goodsig = FALSE;
@@ -759,7 +761,7 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 	size_t nread, nwritten;
 	register char *inptr;
 	GMimeSigner *signer;
-	char *status;
+	char *status, *tmp;
 	int len;
 	
  parse:
@@ -779,9 +781,18 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 	d(printf ("status: %s\n", status));
 	
 	if (strncmp (status, "[GNUPG:] ", 9) != 0) {
+		if (!gpg->utf8)
+			tmp = g_locale_to_utf8 (status, -1, &nread, &nwritten, NULL);
+		else
+			tmp = status;
+		
 		g_set_error (err, GMIME_ERROR, GMIME_ERROR_PARSE_ERROR,
 			     _("Unexpected GnuPG status message encountered:\n\n%s"),
-			     status);
+			     tmp);
+		
+		if (!gpg->utf8)
+			g_free (tmp);
+		
 		return -1;
 	}
 	
@@ -899,9 +910,18 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 		}
 	} else if (!strncmp (status, "UNEXPECTED ", 11)) {
 		/* this is an error */
+		if (!gpg->utf8)
+			tmp = g_locale_to_utf8 (status + 11, -1, &nread, &nwritten, NULL);
+		else
+			tmp = status + 11;
+		
 		g_set_error (err, GMIME_ERROR, GMIME_ERROR_GENERAL,
 			     _("Unexpected response from GnuPG: %s"),
-			     status + 11);
+			     tmp);
+		
+		if (!gpg->utf8)
+			g_free (tmp);
+		
 		return -1;
 	} else if (!strncmp (status, "NODATA", 6)) {
 		/* this is an error */
@@ -910,7 +930,7 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 		diagnostics = gpg_ctx_get_diagnostics (gpg);
 		if (diagnostics && *diagnostics)
 			g_set_error (err, GMIME_ERROR, GMIME_ERROR_GENERAL,
-				     diagnostics);
+				     "%s", diagnostics);
 		else
 			g_set_error (err, GMIME_ERROR, GMIME_ERROR_GENERAL,
 				     _("No data provided"));
@@ -1810,7 +1830,7 @@ g_mime_gpg_context_new (GMimeSession *session, const char *path)
 	g_return_val_if_fail (GMIME_IS_SESSION (session), NULL);
 	g_return_val_if_fail (path != NULL, NULL);
 	
-	ctx = g_object_new (GMIME_TYPE_GPG_CONTEXT, NULL, NULL);
+	ctx = g_object_new (GMIME_TYPE_GPG_CONTEXT, NULL);
 	ctx->path = g_strdup (path);
 	
 	cipher = (GMimeCipherContext *) ctx;
