@@ -22,7 +22,6 @@
 #include <config.h>
 #endif
 
-#include <glib.h>
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
@@ -118,7 +117,7 @@ g_mime_iconv_strndup (iconv_t cd, const char *string, size_t n)
 		 * We just need to grow our outbuffer and try again.
 		 */
 		
-		converted = outbuf - (char *) out;
+		converted = outbuf - out;
 		if (errno == E2BIG) {
 			outlen += inleft * 2 + 16;
 			out = g_realloc (out, outlen + 4);
