@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -193,7 +190,7 @@ g_mime_iconv_init (void)
  * number of times until closed using g_mime_iconv_close().
  *
  * Returns a new conversion descriptor for use with g_mime_iconv() on
- * success or (iconv_t) -1 on fail as well as setting an appropriate
+ * success or (iconv_t) %-1 on fail as well as setting an appropriate
  * errno value.
  **/
 iconv_t
@@ -208,7 +205,7 @@ g_mime_iconv_open (const char *to, const char *from)
 		return (iconv_t) -1;
 	}
 	
-	if (!strcasecmp (from, "x-unknown"))
+	if (!g_ascii_strcasecmp (from, "x-unknown"))
 		from = g_mime_locale_charset ();
 	
 	from = g_mime_charset_iconv_name (from);
@@ -218,11 +215,9 @@ g_mime_iconv_open (const char *to, const char *from)
 	
 	ICONV_CACHE_LOCK ();
 	
-	node = (IconvCacheNode *) cache_node_lookup (iconv_cache, key, TRUE);
-	if (node) {
+	if ((node = (IconvCacheNode *) cache_node_lookup (iconv_cache, key, TRUE))) {
 		if (node->used) {
-			cd = iconv_open (to, from);
-			if (cd == (iconv_t) -1)
+			if ((cd = iconv_open (to, from)) == (iconv_t) -1)
 				goto exception;
 		} else {
 			/* Apparently iconv on Solaris <= 7 segfaults if you pass in
@@ -241,8 +236,7 @@ g_mime_iconv_open (const char *to, const char *from)
 		
 		node->refcount++;
 	} else {
-		cd = iconv_open (to, from);
-		if (cd == (iconv_t) -1)
+		if ((cd = iconv_open (to, from)) == (iconv_t) -1)
 			goto exception;
 		
 		node = iconv_cache_node_new (key, cd);
@@ -276,7 +270,7 @@ g_mime_iconv_open (const char *to, const char *from)
  *
  * Closes the iconv descriptor @cd.
  *
- * Returns 0 on success or -1 on fail as well as setting an
+ * Returns %0 on success or %-1 on fail as well as setting an
  * appropriate errno value.
  **/
 int
@@ -290,8 +284,7 @@ g_mime_iconv_close (iconv_t cd)
 	
 	ICONV_CACHE_LOCK ();
 	
-	key = g_hash_table_lookup (iconv_open_hash, cd);
-	if (key) {
+	if ((key = g_hash_table_lookup (iconv_open_hash, cd))) {
 		g_hash_table_remove (iconv_open_hash, cd);
 		
 		node = (IconvCacheNode *) cache_node_lookup (iconv_cache, key, FALSE);
