@@ -852,7 +852,7 @@ g_mime_message_new (gboolean pretty_headers)
 	GMimeMessage *message;
 	int i;
 	
-	message = g_object_new (GMIME_TYPE_MESSAGE, NULL, NULL);
+	message = g_object_new (GMIME_TYPE_MESSAGE, NULL);
 	
 	if (pretty_headers) {
 		/* Populate with the "standard" rfc822 headers so we can have a standard order */
