@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2000-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -32,17 +29,14 @@
 #include <gmime/gmime-stream.h>
 #include <gmime/internet-address.h>
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define GMIME_TYPE_MESSAGE            (g_mime_message_get_type ())
-#define GMIME_MESSAGE(obj)            (GMIME_CHECK_CAST ((obj), GMIME_TYPE_MESSAGE, GMimeMessage))
-#define GMIME_MESSAGE_CLASS(klass)    (GMIME_CHECK_CLASS_CAST ((klass), GMIME_TYPE_MESSAGE, GMimeMessageClass))
-#define GMIME_IS_MESSAGE(obj)         (GMIME_CHECK_TYPE ((obj), GMIME_TYPE_MESSAGE))
-#define GMIME_IS_MESSAGE_CLASS(klass) (GMIME_CHECK_CLASS_TYPE ((klass), GMIME_TYPE_MESSAGE))
-#define GMIME_MESSAGE_GET_CLASS(obj)  (GMIME_CHECK_GET_CLASS ((obj), GMIME_TYPE_MESSAGE, GMimeMessageClass))
+#define GMIME_MESSAGE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMIME_TYPE_MESSAGE, GMimeMessage))
+#define GMIME_MESSAGE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMIME_TYPE_MESSAGE, GMimeMessageClass))
+#define GMIME_IS_MESSAGE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GMIME_TYPE_MESSAGE))
+#define GMIME_IS_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GMIME_TYPE_MESSAGE))
+#define GMIME_MESSAGE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GMIME_TYPE_MESSAGE, GMimeMessageClass))
 
 typedef struct _GMimeMessage GMimeMessage;
 typedef struct _GMimeMessageClass GMimeMessageClass;
@@ -109,6 +103,7 @@ const char *g_mime_message_get_reply_to (GMimeMessage *message);
 void g_mime_message_add_recipient (GMimeMessage *message, char *type, const char *name, const char *address);
 void g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, const char *string);
 const InternetAddressList *g_mime_message_get_recipients (GMimeMessage *message, const char *type);
+InternetAddressList *g_mime_message_get_all_recipients (GMimeMessage *message);
 
 void g_mime_message_set_subject (GMimeMessage *message, const char *subject);
 const char *g_mime_message_get_subject (GMimeMessage *message);
@@ -130,15 +125,14 @@ void g_mime_message_set_mime_part (GMimeMessage *message, GMimeObject *mime_part
 #ifndef GMIME_DISABLE_DEPRECATED
 ssize_t g_mime_message_write_to_stream (GMimeMessage *message, GMimeStream *stream);
 char *g_mime_message_to_string (GMimeMessage *message);
-#endif /* GMIME_DISABLE_DEPRECATED */
 
 char *g_mime_message_get_body (const GMimeMessage *message, gboolean want_plain, gboolean *is_html);
+#endif /* GMIME_DISABLE_DEPRECATED */
+
 char *g_mime_message_get_headers (GMimeMessage *message);
 
 void g_mime_message_foreach_part (GMimeMessage *message, GMimePartFunc callback, gpointer data);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __GMIME_MESSAGE_H__ */
