@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2000-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -58,6 +55,8 @@ static void mime_part_remove_header (GMimeObject *object, const char *header);
 static char *mime_part_get_headers (GMimeObject *object);
 static ssize_t mime_part_write_to_stream (GMimeObject *object, GMimeStream *stream);
 
+static ssize_t write_disposition (GMimeStream *stream, const char *name, const char *value);
+
 #define NEEDS_DECODING(encoding) (((GMimePartEncodingType) encoding) == GMIME_PART_ENCODING_BASE64 ||   \
 				  ((GMimePartEncodingType) encoding) == GMIME_PART_ENCODING_UUENCODE || \
 				  ((GMimePartEncodingType) encoding) == GMIME_PART_ENCODING_QUOTEDPRINTABLE)
@@ -80,7 +79,7 @@ g_mime_part_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimePart),
-			16,   /* n_preallocs */
+			0,    /* n_preallocs */
 			(GInstanceInitFunc) g_mime_part_init,
 		};
 		
@@ -119,6 +118,8 @@ g_mime_part_init (GMimePart *mime_part, GMimePartClass *klass)
 	mime_part->content_location = NULL;
 	mime_part->content_md5 = NULL;
 	mime_part->content = NULL;
+	
+	g_mime_header_register_writer (((GMimeObject *) mime_part)->headers, "Content-Disposition", write_disposition);
 }
 
 static void
@@ -165,6 +166,28 @@ static char *headers[] = {
 	NULL
 };
 
+static ssize_t
+write_disposition (GMimeStream *stream, const char *name, const char *value)
+{
+	GMimeDisposition *disposition;
+	ssize_t nwritten;
+	GString *out;
+	
+	out = g_string_new ("");
+	g_string_printf (out, "%s: ", name);
+	
+	disposition = g_mime_disposition_new (value);
+	g_string_append (out, disposition->disposition);
+	
+	g_mime_param_write_to_string (disposition->params, TRUE, out);
+	g_mime_disposition_destroy (disposition);
+	
+	nwritten = g_mime_stream_write (stream, out->str, out->len);
+	g_string_free (out, TRUE);
+	
+	return nwritten;
+}
+
 static void
 set_disposition (GMimePart *mime_part, const char *disposition)
 {
@@ -174,6 +197,18 @@ set_disposition (GMimePart *mime_part, const char *disposition)
 	mime_part->disposition = g_mime_disposition_new (disposition);
 }
 
+static void
+sync_content_disposition (GMimePart *mime_part)
+{
+	char *str;
+	
+	if (mime_part->disposition) {
+		str = g_mime_disposition_header (mime_part->disposition, FALSE);
+		g_mime_header_set (GMIME_OBJECT (mime_part)->headers, "Content-Disposition", str);
+		g_free (str);
+	}
+}
+
 static gboolean
 process_header (GMimeObject *object, const char *header, const char *value)
 {
@@ -182,7 +217,7 @@ process_header (GMimeObject *object, const char *header, const char *value)
 	int i;
 	
 	for (i = 0; headers[i]; i++) {
-		if (!strcasecmp (headers[i], header))
+		if (!g_ascii_strcasecmp (headers[i], header))
 			break;
 	}
 	
@@ -223,7 +258,7 @@ mime_part_add_header (GMimeObject *object, const char *header, const char *value
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8)) {
+	if (!g_ascii_strncasecmp ("Content-", header, 8)) {
 		if (process_header (object, header, value))
 			g_mime_header_add (object->headers, header, value);
 		else
@@ -237,7 +272,7 @@ mime_part_set_header (GMimeObject *object, const char *header, const char *value
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8)) {
+	if (!g_ascii_strncasecmp ("Content-", header, 8)) {
 		if (process_header (object, header, value))
 			g_mime_header_set (object->headers, header, value);
 		else
@@ -251,7 +286,7 @@ mime_part_get_header (GMimeObject *object, const char *header)
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_ascii_strncasecmp ("Content-", header, 8))
 		return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
 	else
 		return NULL;
@@ -263,7 +298,7 @@ mime_part_remove_header (GMimeObject *object, const char *header)
 	/* Make sure that the header is a Content-* header, else it
 	   doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_ascii_strncasecmp ("Content-", header, 8))
 		GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
@@ -364,8 +399,7 @@ mime_part_write_to_stream (GMimeObject *object, GMimeStream *stream)
 	ssize_t nwritten, total = 0;
 	
 	/* write the content headers */
-	nwritten = g_mime_header_write_to_stream (object->headers, stream);
-	if (nwritten == -1)
+	if ((nwritten = g_mime_header_write_to_stream (object->headers, stream)) == -1)
 		return -1;
 	
 	total += nwritten;
@@ -376,8 +410,7 @@ mime_part_write_to_stream (GMimeObject *object, GMimeStream *stream)
 	
 	total++;
 	
-	nwritten = write_content (mime_part, stream);
-	if (nwritten == -1)
+	if ((nwritten = write_content (mime_part, stream)) == -1)
 		return -1;
 	
 	total += nwritten;
@@ -401,7 +434,7 @@ g_mime_part_new ()
 	GMimePart *mime_part;
 	GMimeContentType *type;
 	
-	mime_part = g_object_new (GMIME_TYPE_PART, NULL, NULL);
+	mime_part = g_object_new (GMIME_TYPE_PART, NULL);
 	
 	type = g_mime_content_type_new ("text", "plain");
 	g_mime_object_set_content_type (GMIME_OBJECT (mime_part), type);
@@ -425,7 +458,7 @@ g_mime_part_new_with_type (const char *type, const char *subtype)
 	GMimePart *mime_part;
 	GMimeContentType *content_type;
 	
-	mime_part = g_object_new (GMIME_TYPE_PART, NULL, NULL);
+	mime_part = g_object_new (GMIME_TYPE_PART, NULL);
 	
 	content_type = g_mime_content_type_new (type, subtype);
 	g_mime_object_set_content_type (GMIME_OBJECT (mime_part), content_type);
@@ -547,7 +580,7 @@ g_mime_part_get_content_id (GMimePart *mime_part)
 /**
  * g_mime_part_set_content_md5:
  * @mime_part: Mime part
- * @content_md5: content md5 or NULL to generate the md5 digest.
+ * @content_md5: content md5 or %NULL to generate the md5 digest.
  *
  * Set the content md5 for the specified mime part.
  **/
@@ -559,7 +592,8 @@ g_mime_part_set_content_md5 (GMimePart *mime_part, const char *content_md5)
 	GMimeStreamFilter *filtered_stream;
 	GMimeFilter *md5_filter;
 	GMimeStream *stream;
-	int state, save;
+	guint32 save = 0;
+	int state = 0;
 	size_t len;
 	
 	g_return_if_fail (GMIME_IS_PART (mime_part));
@@ -595,10 +629,9 @@ g_mime_part_set_content_md5 (GMimePart *mime_part, const char *content_md5)
 		g_mime_filter_md5_get_digest ((GMimeFilterMd5 *) md5_filter, digest);
 		g_object_unref (md5_filter);
 		
-		state = save = 0;
 		len = g_mime_utils_base64_encode_close (digest, 16, b64digest, &state, &save);
 		b64digest[len] = '\0';
-		g_strstrip (b64digest);
+		g_strstrip ((char *) b64digest);
 		
 		content_md5 = (const char *) b64digest;
 	}
@@ -614,8 +647,8 @@ g_mime_part_set_content_md5 (GMimePart *mime_part, const char *content_md5)
  *
  * Verify the content md5 for the specified mime part.
  *
- * Returns TRUE if the md5 is valid or FALSE otherwise. Note: will
- * return FALSE if the mime part does not contain a Content-MD5.
+ * Returns %TRUE if the md5 is valid or %FALSE otherwise. Note: will
+ * return %FALSE if the mime part does not contain a Content-MD5.
  **/
 gboolean
 g_mime_part_verify_content_md5 (GMimePart *mime_part)
@@ -625,7 +658,8 @@ g_mime_part_verify_content_md5 (GMimePart *mime_part)
 	GMimeStreamFilter *filtered_stream;
 	GMimeFilter *md5_filter;
 	GMimeStream *stream;
-	int state, save;
+	guint32 save = 0;
+	int state = 0;
 	size_t len;
 	
 	g_return_val_if_fail (GMIME_IS_PART (mime_part), FALSE);
@@ -660,12 +694,11 @@ g_mime_part_verify_content_md5 (GMimePart *mime_part)
 	g_mime_filter_md5_get_digest ((GMimeFilterMd5 *) md5_filter, digest);
 	g_object_unref (md5_filter);
 	
-	state = save = 0;
 	len = g_mime_utils_base64_encode_close (digest, 16, b64digest, &state, &save);
 	b64digest[len] = '\0';
-	g_strstrip (b64digest);
+	g_strstrip ((char *) b64digest);
 	
-	return !strcmp (b64digest, mime_part->content_md5);
+	return !strcmp ((char *) b64digest, mime_part->content_md5);
 }
 
 
@@ -790,10 +823,10 @@ g_mime_part_set_encoding (GMimePart *mime_part, GMimePartEncodingType encoding)
  *
  * Returns the content encoding for the specified mime part. The
  * return value will be one of the following:
- * GMIME_PART_ENCODING_DEFAULT, GMIME_PART_ENCODING_7BIT,
- * GMIME_PART_ENCODING_8BIT, GMIME_PART_ENCODING_BINARY,
- * GMIME_PART_ENCODING_BASE64, GMIME_PART_ENCODING_QUOTEDPRINTABLE
- * or GMIME_PART_ENCODING_UUENCODE.
+ * #GMIME_PART_ENCODING_DEFAULT, #GMIME_PART_ENCODING_7BIT,
+ * #GMIME_PART_ENCODING_8BIT, #GMIME_PART_ENCODING_BINARY,
+ * #GMIME_PART_ENCODING_BASE64, #GMIME_PART_ENCODING_QUOTEDPRINTABLE
+ * or #GMIME_PART_ENCODING_UUENCODE.
  **/
 GMimePartEncodingType
 g_mime_part_get_encoding (GMimePart *mime_part)
@@ -811,11 +844,11 @@ g_mime_part_get_encoding (GMimePart *mime_part)
  * Gets the string value of the content encoding.
  *
  * Returns the encoding type as a string. Available
- * values for the encoding are: GMIME_PART_ENCODING_DEFAULT,
- * GMIME_PART_ENCODING_7BIT, GMIME_PART_ENCODING_8BIT,
- * GMIME_PART_ENCODING_BINARY, GMIME_PART_ENCODING_BASE64,
- * GMIME_PART_ENCODING_QUOTEDPRINTABLE and
- * GMIME_PART_ENCODING_UUENCODE.
+ * values for the encoding are: #GMIME_PART_ENCODING_DEFAULT,
+ * #GMIME_PART_ENCODING_7BIT, #GMIME_PART_ENCODING_8BIT,
+ * #GMIME_PART_ENCODING_BINARY, #GMIME_PART_ENCODING_BASE64,
+ * #GMIME_PART_ENCODING_QUOTEDPRINTABLE and
+ * #GMIME_PART_ENCODING_UUENCODE.
  **/
 const char *
 g_mime_part_encoding_to_string (GMimePartEncodingType encoding)
@@ -847,40 +880,30 @@ g_mime_part_encoding_to_string (GMimePartEncodingType encoding)
  * Gets the content encoding enumeration value based on the input
  * string.
  *
- * Returns the encoding string as a GMimePartEncodingType.  Available
- * values for the encoding are: GMIME_PART_ENCODING_DEFAULT,
- * GMIME_PART_ENCODING_7BIT, GMIME_PART_ENCODING_8BIT,
- * GMIME_PART_ENCODING_BINARY, GMIME_PART_ENCODING_BASE64,
- * GMIME_PART_ENCODING_QUOTEDPRINTABLE and
- * GMIME_PART_ENCODING_UUENCODE.
+ * Returns the encoding string as a #GMimePartEncodingType.  Available
+ * values for the encoding are: #GMIME_PART_ENCODING_DEFAULT,
+ * #GMIME_PART_ENCODING_7BIT, #GMIME_PART_ENCODING_8BIT,
+ * #GMIME_PART_ENCODING_BINARY, #GMIME_PART_ENCODING_BASE64,
+ * #GMIME_PART_ENCODING_QUOTEDPRINTABLE and
+ * #GMIME_PART_ENCODING_UUENCODE.
  **/
 GMimePartEncodingType
 g_mime_part_encoding_from_string (const char *encoding)
 {
-	if (!strcasecmp (encoding, "7bit"))
+	if (!g_ascii_strcasecmp (encoding, "7bit"))
 		return GMIME_PART_ENCODING_7BIT;
-	else if (!strcasecmp (encoding, "8bit"))
+	else if (!g_ascii_strcasecmp (encoding, "8bit"))
 		return GMIME_PART_ENCODING_8BIT;
-	else if (!strcasecmp (encoding, "binary"))
+	else if (!g_ascii_strcasecmp (encoding, "binary"))
 		return GMIME_PART_ENCODING_BINARY;
-	else if (!strcasecmp (encoding, "base64"))
+	else if (!g_ascii_strcasecmp (encoding, "base64"))
 		return GMIME_PART_ENCODING_BASE64;
-	else if (!strcasecmp (encoding, "quoted-printable"))
+	else if (!g_ascii_strcasecmp (encoding, "quoted-printable"))
 		return GMIME_PART_ENCODING_QUOTEDPRINTABLE;
-	else if (!strcasecmp (encoding, "x-uuencode"))
+	else if (!g_ascii_strcasecmp (encoding, "x-uuencode"))
 		return GMIME_PART_ENCODING_UUENCODE;
-	else return GMIME_PART_ENCODING_DEFAULT;
-}
-
-
-static void
-sync_content_disposition (GMimePart *mime_part)
-{
-	char *str;
-	
-	str = g_mime_disposition_header (mime_part->disposition, FALSE);
-	g_mime_header_set (GMIME_OBJECT (mime_part)->headers, "Content-Disposition", str);
-	g_free (str);
+	else
+		return GMIME_PART_ENCODING_DEFAULT;
 }
 
 
@@ -974,7 +997,7 @@ g_mime_part_add_content_disposition_parameter (GMimePart *mime_part, const char
  * @attribute, or %NULL if the parameter does not exist.
  *
  * Returns the value of a previously defined content-disposition
- * parameter specified by #name.
+ * parameter specified by @attribute.
  **/
 const char *
 g_mime_part_get_content_disposition_parameter (GMimePart *mime_part, const char *attribute)
@@ -1050,7 +1073,7 @@ g_mime_part_get_filename (const GMimePart *mime_part)
  * @len: raw content length
  *
  * WARNING: This interface is deprecated. Use
- * #g_mime_part_set_content_object instead.
+ * g_mime_part_set_content_object() instead.
  *
  * Sets the content of the Mime Part (only non-multiparts)
  **/
@@ -1077,7 +1100,7 @@ g_mime_part_set_content (GMimePart *mime_part, const char *content, size_t len)
  * @content: raw mime part content.
  *
  * WARNING: This interface is deprecated. Use
- * #g_mime_part_set_content_object instead.
+ * g_mime_part_set_content_object() instead.
  *
  * Sets the content of the Mime Part (only non-multiparts)
  **/
@@ -1106,7 +1129,7 @@ g_mime_part_set_content_byte_array (GMimePart *mime_part, GByteArray *content)
  * @encoding: content encoding
  *
  * WARNING: This interface is deprecated. Use
- * #g_mime_part_set_content_object instead.
+ * g_mime_part_set_content_object() instead.
  *
  * Sets the encoding type and raw content on the mime part after
  * decoding the content.
@@ -1211,7 +1234,7 @@ g_mime_part_get_content_object (const GMimePart *mime_part)
  * of the raw data buffer.
  *
  * WARNING: This interface is deprecated. Use
- * #g_mime_get_content_object instead.
+ * g_mime_part_get_content_object() instead.
  * 
  * Returns a const char * pointer to the raw contents of the MIME Part
  * and sets @len to the length of the buffer. Note: textual content
@@ -1249,22 +1272,22 @@ g_mime_part_get_content (const GMimePart *mime_part, size_t *len)
 		g_object_unref (cache);
 		
 		*len = buf->len;
-		retval = buf->data;
+		retval = (char *) buf->data;
 	} else {
 		GByteArray *buf = GMIME_STREAM_MEM (stream)->buffer;
-		int start_index = 0;
-		int end_index = buf->len;
+		off_t end_index = (off_t) buf->len;
+		off_t start_index = 0;
 		
 		/* check boundaries */
 		if (stream->bound_start >= 0)
-			start_index = CLAMP (stream->bound_start, 0, buf->len);
+			start_index = CLAMP (stream->bound_start, 0, (off_t) buf->len);
 		if (stream->bound_end >= 0)
-			end_index = CLAMP (stream->bound_end, 0, buf->len);
+			end_index = CLAMP (stream->bound_end, 0, (off_t) buf->len);
 		if (end_index < start_index)
 			end_index = start_index;
 		
 		*len = end_index - start_index;
-		retval = buf->data + start_index;
+		retval = (char *) buf->data + start_index;
 	}
 	
 	return retval;
@@ -1279,9 +1302,9 @@ g_mime_part_get_content (const GMimePart *mime_part, size_t *len)
  * Writes the contents of the MIME Part to @stream.
  *
  * WARNING: This interface is deprecated. Use
- * #g_mime_object_write_to_stream instead.
+ * g_mime_object_write_to_stream() instead.
  *
- * Returns the number of bytes written or -1 on fail.
+ * Returns the number of bytes written or %-1 on fail.
  **/
 ssize_t
 g_mime_part_write_to_stream (GMimePart *mime_part, GMimeStream *stream)
@@ -1300,7 +1323,7 @@ g_mime_part_write_to_stream (GMimePart *mime_part, GMimeStream *stream)
  * Allocates a string buffer containing the MIME Part.
  *
  * WARNING: This interface is deprecated. Use
- * #g_mime_object_to_string instead.
+ * g_mime_object_to_string() instead.
  *
  * Returns an allocated string containing the MIME Part.
  **/
