@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -31,8 +28,9 @@
 
 #include "internet-address.h"
 #include "gmime-table-private.h"
-#include "gmime-utils.h"
+#include "gmime-parse-utils.h"
 #include "gmime-iconv-utils.h"
+#include "gmime-utils.h"
 
 
 #ifdef ENABLE_WARNINGS
@@ -43,11 +41,6 @@
 
 #define d(x)
 
-/* public functions that we don't care for the user of GMime to know or care about */
-void decode_lwsp (const char **in);
-char *decode_word (const char **in);
-char *decode_addrspec (const char **in);
-
 
 /**
  * internet_address_new:
@@ -227,8 +220,6 @@ internet_address_set_addr (InternetAddress *ia, const char *addr)
 void
 internet_address_set_group (InternetAddress *ia, InternetAddressList *group)
 {
-	/*InternetAddressList *members, *next; */
-	
 	g_return_if_fail (ia != NULL);
 	g_return_if_fail (ia->type != INTERNET_ADDRESS_NAME);
 	
@@ -266,8 +257,8 @@ internet_address_add_member (InternetAddress *ia, InternetAddress *member)
 InternetAddressType
 internet_address_get_type (InternetAddress *ia)
 {
-	g_return_if_fail (ia != NULL);
-
+	g_return_val_if_fail (ia != NULL, INTERNET_ADDRESS_NONE);
+	
 	return ia->type;
 }
 
@@ -280,8 +271,8 @@ internet_address_get_type (InternetAddress *ia)
 const char *
 internet_address_get_name (InternetAddress *ia)
 {
-	g_return_if_fail (ia != NULL);
-
+	g_return_val_if_fail (ia != NULL, NULL);
+	
 	return ia->name;
 }
 
@@ -295,9 +286,9 @@ internet_address_get_name (InternetAddress *ia)
 const char *
 internet_address_get_addr (InternetAddress *ia)
 {
-	g_return_if_fail (ia != NULL);
-	g_return_if_fail (ia->type != INTERNET_ADDRESS_GROUP);
-
+	g_return_val_if_fail (ia != NULL, NULL);
+	g_return_val_if_fail (ia->type != INTERNET_ADDRESS_GROUP, NULL);
+	
 	return ia->value.addr;
 }
 
@@ -306,14 +297,14 @@ internet_address_get_addr (InternetAddress *ia)
  * internet_address_get_members:
  * @ia: internet address
  *
- * Returns the list of internet addresses
+ * Returns the list of internet addresses.
  **/
 const InternetAddressList *
 internet_address_get_members (InternetAddress *ia)
 {
-	g_return_if_fail (ia != NULL);
-	g_return_if_fail (ia->type != INTERNET_ADDRESS_NAME);
-
+	g_return_val_if_fail (ia != NULL, NULL);
+	g_return_val_if_fail (ia->type != INTERNET_ADDRESS_NAME, NULL);
+	
 	return ia->value.members;
 }
 
@@ -426,30 +417,29 @@ internet_address_list_concat (InternetAddressList *a, InternetAddressList *b)
  * internet_address_list_next:
  * @list: list of internet addresses
  *
- * Returns the following node in @list.
+ * Advances to the next address node in the #InternetAddessList.
+ *
+ * Returns the next address node in the #InternetAddessList.
  **/
 InternetAddressList *
 internet_address_list_next (const InternetAddressList *list)
 {
-	if (!list)
-		return NULL;
-
-	return list->next;
+	return list ? list->next : NULL;
 }
 
+
 /**
  * internet_address_list_get_address:
  * @list: list of internet addresses
  *
+ * Gets the #InternetAddress currently pointed to in @list.
+ *
  * Returns the #InternetAddress currently pointed to in @list.
  **/
 InternetAddress *
 internet_address_list_get_address (const InternetAddressList *list)
 {
-	if (!list)
-		return NULL;
-
-	return list->address;
+	return list ? list->address : NULL;
 }
 
 /**
@@ -601,264 +591,6 @@ internet_address_list_to_string (const InternetAddressList *list, gboolean encod
 	return str;
 }
 
-
-void
-decode_lwsp (const char **in)
-{
-	const char *inptr = *in;
-	
-	while (*inptr && (*inptr == '(' || is_lwsp (*inptr))) {
-		while (*inptr && is_lwsp (*inptr))
-			inptr++;
-		
-		/* skip over any comments */
-		if (*inptr == '(') {
-			int depth = 1;
-			
-			inptr++;
-			while (*inptr && depth) {
-				if (*inptr == '\\' && *(inptr + 1))
-					inptr++;
-				else if (*inptr == '(')
-					depth++;
-				else if (*inptr == ')')
-					depth--;
-				
-				inptr++;
-			}
-		}
-	}
-	
-	*in = inptr;
-}
-
-static char *
-decode_quoted_string (const char **in)
-{
-	const char *inptr = *in;
-	char *out = NULL;
-	
-	decode_lwsp (&inptr);
-	if (*inptr == '"') {
-		out = (char *) inptr;
-		
-		inptr++;
-		while (*inptr && *inptr != '"') {
-			if (*inptr == '\\')
-				inptr++;
-			
-			if (*inptr)
-				inptr++;
-		}
-		
-		if (*inptr == '"')
-			inptr++;
-		
-		out = g_strndup (out, inptr - out);
-	}
-	
-	*in = inptr;
-	
-	return out;
-}
-
-static char *
-decode_atom (const char **in)
-{
-	const char *inptr = *in, *start;
-	
-	decode_lwsp (&inptr);
-	start = inptr;
-	while (is_atom (*inptr))
-		inptr++;
-	*in = inptr;
-	if (inptr > start)
-		return g_strndup (start, inptr - start);
-	else
-		return NULL;
-}
-
-char *
-decode_word (const char **in)
-{
-	const char *inptr = *in;
-	
-	decode_lwsp (&inptr);
-	if (*inptr == '"') {
-		*in = inptr;
-		return decode_quoted_string (in);
-	} else {
-		*in = inptr;
-		return decode_atom (in);
-	}
-}
-
-static gboolean
-decode_subliteral (const char **in, GString *domain)
-{
-	const char *inptr = *in;
-	gboolean got = FALSE;
-	
-	while (*inptr && *inptr != '.' && *inptr != ']') {
-		if (is_dtext (*inptr)) {
-			g_string_append_c (domain, *inptr);
-			inptr++;
-			got = TRUE;
-		} else if (is_lwsp (*inptr))
-			decode_lwsp (&inptr);
-		else
-			break;
-	}
-	
-	*in = inptr;
-	
-	return got;
-}
-
-static void
-decode_domain_literal (const char **in, GString *domain)
-{
-	const char *inptr = *in;
-	
-	decode_lwsp (&inptr);
-	while (*inptr && *inptr != ']') {
-		if (decode_subliteral (&inptr, domain) && *inptr == '.') {
-			g_string_append_c (domain, *inptr);
-			inptr++;
-		} else if (*inptr != ']') {
-			w(g_warning ("Malformed domain-literal, unexpected char '%c': %s",
-				     *inptr, *in));
-			
-			/* try and skip to the next char ?? */
-			inptr++;
-		}
-	}
-	
-	*in = inptr;
-}
-
-static char *
-decode_domain (const char **in)
-{
-	const char *inptr, *save;
-	GString *domain;
-	char *dom, *atom;
-	
-	domain = g_string_new ("");
-	
-	inptr = *in;
-	while (inptr && *inptr) {
-		decode_lwsp (&inptr);
-		if (*inptr == '[') {
-			/* domain literal */
-			g_string_append_c (domain, '[');
-			inptr++;
-			
-			decode_domain_literal (&inptr, domain);
-			
-			if (*inptr == ']') {
-				g_string_append_c (domain, ']');
-				inptr++;
-			} else
-				w(g_warning ("Missing ']' in domain-literal: %s", *in));
-		} else {
-			if (!(atom = decode_atom (&inptr))) {
-				w(g_warning ("Unexpected char '%c' in domain: %s", *inptr, *in));
-				/* remove the last '.' */
-				if (domain->len && domain->str[domain->len - 1] == '.')
-					g_string_truncate (domain, domain->len - 1);
-				break;
-			}
-			
-			g_string_append (domain, atom);
-			g_free (atom);
-		}
-		
-		save = inptr;
-		decode_lwsp (&inptr);
-		if (*inptr != '.') {
-			inptr = save;
-			break;
-		}
-		
-		g_string_append_c (domain, '.');
-		inptr++;
-	}
-	
-	if (domain->len)
-		dom = domain->str;
-	else
-		dom = NULL;
-	
-	g_string_free (domain, dom ? FALSE : TRUE);
-	
-	*in = inptr;
-	
-	return dom;
-}
-
-char *
-decode_addrspec (const char **in)
-{
-	char *domain, *word, *str = NULL;
-	const char *inptr;
-	GString *addrspec;
-	
-	decode_lwsp (in);
-	inptr = *in;
-	
-	if (!(word = decode_word (&inptr))) {
-		w(g_warning ("No local-part in addr-spec: %s", *in));
-		return NULL;
-	}
-	
-	addrspec = g_string_new (word);
-	g_free (word);
-	
-	/* get the rest of the local-part */
-	decode_lwsp (&inptr);
-	while (*inptr == '.') {
-		g_string_append_c (addrspec, *inptr++);
-		word = decode_word (&inptr);
-		if (word) {
-			g_string_append (addrspec, word);
-			decode_lwsp (&inptr);
-			g_free (word);
-		} else {
-			w(g_warning ("Invalid local-part in addr-spec: %s", *in));
-			goto exception;
-		}
-	}
-	
-	/* we should be at the '@' now... */
-	if (*inptr++ != '@') {
-		w(g_warning ("Invalid addr-spec; missing '@': %s", *in));
-		goto exception;
-	}
-	
-	if (!(domain = decode_domain (&inptr))) {
-		w(g_warning ("No domain in addr-spec: %s", *in));
-		goto exception;
-	}
-	
-	g_string_append_c (addrspec, '@');
-	g_string_append (addrspec, domain);
-	g_free (domain);
-	
-	str = addrspec->str;
-	g_string_free (addrspec, FALSE);
-	
-	*in = inptr;
-	
-	return str;
-	
- exception:
-	
-	g_string_free (addrspec, TRUE);
-	
-	return NULL;
-}
-
 static InternetAddress *
 decode_mailbox (const char **in)
 {
@@ -919,7 +651,12 @@ decode_mailbox (const char **in)
 		if (name)
 			g_string_free (name, TRUE);
 		g_string_free (addr, TRUE);
-		*in = inptr + 1;
+		
+		/* comma will be eaten by our caller */
+		if (*inptr != ',')
+			*in = inptr + 1;
+		else
+			*in = inptr;
 		
 		return NULL;
 	}
@@ -929,8 +666,7 @@ decode_mailbox (const char **in)
 	while (*inptr == '.' && pre) {
 		inptr++;
 		g_free (pre);
-		pre = decode_word (&inptr);
-		if (pre) {
+		if ((pre = decode_word (&inptr))) {
 			g_string_append_c (addr, '.');
 			g_string_append (addr, pre);
 		}
@@ -943,8 +679,7 @@ decode_mailbox (const char **in)
 		char *domain;
 		
 		inptr++;
-		domain = decode_domain (&inptr);
-		if (domain) {
+		if ((domain = decode_domain (&inptr))) {
 			g_string_append_c (addr, '@');
 			g_string_append (addr, domain);
 			g_free (domain);
@@ -973,8 +708,7 @@ decode_mailbox (const char **in)
 		comment = (char *) inptr;
 		decode_lwsp (&inptr);
 		if (inptr > comment) {
-			comment = memchr (comment, '(', inptr - comment);
-			if (comment) {
+			if ((comment = memchr (comment, '(', inptr - comment))) {
 				const char *cend;
 				
 				/* find the end of the comment */
@@ -1005,8 +739,7 @@ decode_mailbox (const char **in)
 			 * converting to UTF-8 */
 			char *buf;
 			
-			buf = g_mime_iconv_locale_to_utf8 (name->str);
-			if (buf) {
+			if ((buf = g_mime_iconv_locale_to_utf8 (name->str))) {
 				g_string_truncate (name, 0);
 				g_string_append (name, buf);
 				g_free (buf);
@@ -1063,8 +796,7 @@ decode_address (const char **in)
 		while (*inptr && *inptr != ';') {
 			InternetAddress *member;
 			
-			member = decode_mailbox (&inptr);
-			if (member) {
+			if ((member = decode_mailbox (&inptr))) {
 				tail->next = g_new (InternetAddressList, 1);
 				tail = tail->next;
 				tail->next = NULL;
@@ -1075,8 +807,7 @@ decode_address (const char **in)
 			while (*inptr == ',') {
 				inptr++;
 				decode_lwsp (&inptr);
-				member = decode_mailbox (&inptr);
-				if (member) {
+				if ((member = decode_mailbox (&inptr))) {
 					tail->next = g_new (InternetAddressList, 1);
 					tail = tail->next;
 					tail->next = NULL;
@@ -1151,8 +882,7 @@ internet_address_parse_string (const char *string)
 		else if (*inptr) {
 			w(g_warning ("Parse error at '%s': expected ','", inptr));
 			/* try skipping to the next address */
-			inptr = strchr (inptr, ',');
-			if (inptr)
+			if ((inptr = strchr (inptr, ',')))
 				inptr++;
 		}
 	}
