@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2002 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,11 +14,14 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -42,7 +43,7 @@
 #define PRINT_MIME_STRUCT
 /*#define TEST_WRITE_TO_STREAM*/
 
-void
+static void
 print_depth (int depth)
 {
 	int i;
@@ -51,7 +52,7 @@ print_depth (int depth)
 		fprintf (stdout, "   ");
 }
 
-void
+static void
 print_mime_struct (GMimeObject *part, int depth)
 {
 	const GMimeContentType *type;
@@ -85,7 +86,7 @@ print_mime_struct (GMimeObject *part, int depth)
 	}
 }
 
-void
+static void
 test_parser (GMimeStream *stream)
 {
 	GMimeParser *parser;
@@ -98,17 +99,17 @@ test_parser (GMimeStream *stream)
 	parser = g_mime_parser_new ();
 	g_mime_parser_init_with_stream (parser, stream);
 	
-	ZenTimerStart();
+	ZenTimerStart (NULL);
 	message = g_mime_parser_construct_message (parser);
-	ZenTimerStop();
-	ZenTimerReport ("gmime::parser_construct_message");
+	ZenTimerStop (NULL);
+	ZenTimerReport (NULL, "gmime::parser_construct_message");
 	
 	g_object_unref (parser);
 	
-	ZenTimerStart();
+	ZenTimerStart (NULL);
 	text = g_mime_message_to_string (message);
-	ZenTimerStop();
-	ZenTimerReport ("gmime::message_to_string");
+	ZenTimerStop (NULL);
+	ZenTimerReport (NULL, "gmime::message_to_string");
 	/*fprintf (stdout, "Result should match previous MIME message dump\n\n%s\n", text);*/
 	g_free (text);
 	
@@ -186,8 +187,7 @@ int main (int argc, char **argv)
 	else
 		return 0;
 	
-	fd = open (filename, O_RDONLY);
-	if (fd == -1)
+	if ((fd = open (filename, O_RDONLY)) == -1)
 		return 0;
 	
 #ifdef STREAM_MMAP
